Struct MapErr
struct MapErr<B, F> { ... }
Body returned by the map_err combinator.
Implementations
impl<B, F> MapErr<B, F>
fn get_ref(self: &Self) -> &BGet a reference to the inner body
fn get_mut(self: &mut Self) -> &mut BGet a mutable reference to the inner body
fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut B>Get a pinned mutable reference to the inner body
fn into_inner(self: Self) -> BConsume
self, returning the inner body
impl<'__pin, B, F> Unpin for MapErr<B, F>
impl<B, F> Debug for MapErr<B, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<B, F> Freeze for MapErr<B, F>
impl<B, F> RefUnwindSafe for MapErr<B, F>
impl<B, F> Send for MapErr<B, F>
impl<B, F> Sync for MapErr<B, F>
impl<B, F> UnsafeUnpin for MapErr<B, F>
impl<B, F> UnwindSafe for MapErr<B, F>
impl<B, F, E> Body for MapErr<B, F>
fn poll_frame(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Result<Frame<<Self as >::Data>, <Self as >::Error>>>fn is_end_stream(self: &Self) -> boolfn size_hint(self: &Self) -> SizeHint
impl<B: $crate::clone::Clone, F: $crate::clone::Clone> Clone for MapErr<B, F>
fn clone(self: &Self) -> MapErr<B, F>
impl<B: $crate::marker::Copy, F: $crate::marker::Copy> Copy for MapErr<B, F>
impl<T> Any for MapErr<B, F>
fn type_id(self: &Self) -> TypeId
impl<T> BodyExt for MapErr<B, F>
impl<T> Borrow for MapErr<B, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for MapErr<B, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for MapErr<B, F>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for MapErr<B, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for MapErr<B, F>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for MapErr<B, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for MapErr<B, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for MapErr<B, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>