Struct Frame
struct Frame<'a, T: ?Sized>(_)
Future that resolves to the next frame from a Body.
Implementations
impl<'a, T> Freeze for Frame<'a, T>
impl<'a, T> RefUnwindSafe for Frame<'a, T>
impl<'a, T> Send for Frame<'a, T>
impl<'a, T> Sync for Frame<'a, T>
impl<'a, T> Unpin for Frame<'a, T>
impl<'a, T> UnsafeUnpin for Frame<'a, T>
impl<'a, T> UnwindSafe for Frame<'a, T>
impl<'a, T: $crate::fmt::Debug + ?Sized> Debug for Frame<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<F> IntoFuture for Frame<'a, T>
fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture
impl<T> Any for Frame<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Frame<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Frame<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Frame<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Frame<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Frame<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Frame<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: Body + Unpin + ?Sized> Future for Frame<'_, T>
fn poll(self: Pin<&mut Self>, ctx: &mut Context<'_>) -> Poll<<Self as >::Output>